@@ -1,13 +1,9 @@
-readSDML <- function(file="", text=NULL, validate=FALSE,
-                     read.description=FALSE)
+readSDML <- function(file = "", text = NULL, validate = FALSE,
+                     read.description = FALSE)
 {
-  if (is.null(text))
-    tree <- xmlTreeParse(file=file, asText=FALSE, validate=validate,
-                         handler=handlersSDML(), asTree=TRUE)
-  else 
-    tree <- xmlTreeParse(file=text, asText=TRUE, validate=validate,
-                         handler=handlersSDML(), asTree=TRUE)
-    
+  tree <- xmlTreeParse(file=file, asText=!is.null(text), validate=validate,
+                       handler=handlersSDML(), asTree=TRUE)
+
   ## is this file a StatDataML file ?    
   if (xmlName(xmlRoot(tree)) != "StatDataML")
     stop("This is no StatDataML file");
